==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/admin/messages/fr/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Information</strong>',
  '<strong>Profile</strong> Permissions' => 'Autorisations du <strong>profil</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Paramètres</strong> et configuration',
  '<strong>User</strong> administration' => 'Gestion des <strong>utilisateurs</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Attention:</strong> tous les paramètres d\'autorisation individuels du profil sont réinitialisés!',
  'Accept user: <strong>{displayName}</strong> ' => 'Approuver l\'utilisateur : <strong>{displayName}</strong>',
  'Account' => 'Compte',
  'Account Request for \'{displayName}\' has been approved.' => 'La demande de compte pour "{displayName}" a été acceptée.',
  'Account Request for \'{displayName}\' has been declined.' => 'La demande de compte pour "{displayName}" a été refusée.',
  'Actions' => 'Actions',
  'Active users' => 'Utilisateurs actifs',
  'Add Groups...' => 'Ajouter un groupe',
  'Add new category' => 'Ajouter une catégorie',
  'Add new field' => 'Ajouter un champ',
  'Add new group' => 'Ajouter un groupe',
  'Add new members...' => 'Ajouter des membres...',
  'Add new user' => 'Ajouter un nouvel utilisateur',
  'Administrator group could not be deleted!' => 'Le groupe Administrateur ne peut pas être supprimé!',
  'All open registration invitations were successfully deleted.' => 'Toutes les invitations d\'inscription ont été supprimées avec succès.',
  'All the personal data of this user will be irrevocably deleted.' => 'Toutes les données de cet utilisateur seront irrévocablement supprimées.',
  'Allow' => 'Autoriser',
  'Allow users to block each other' => 'Permettre aux utilisateurs de se bloquer mutuellement',
  'Allow users to set individual permissions for their own profile?' => 'Permettre aux utilisateurs de définir des autorisations individuelles pour leur propre profil ?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Autoriser un accès limité pour les utilisateurs non identifiés (visiteurs)',
  'Applied to new or existing users without any other group membership.' => 'Appliqué aux utilisateurs nouveaux ou existants sans autre appartenance à un groupe.',
  'Apply' => 'Appliquer',
  'Approve' => 'Approuver',
  'Approve all selected' => 'Approuver tous les sélectionnés',
  'Are you really sure that you want to disable this user?' => 'Êtes-vous vraiment sûr de vouloir désactiver cet utilisateur ?',
  'Are you really sure that you want to enable this user?' => 'Êtes-vous vraiment sûr de vouloir activer cet utilisateur ?',
  'Are you really sure that you want to impersonate this user?' => 'Êtes-vous sûr de vouloir incarner cet utilisateur ?',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => 'Êtes-vous vraiment sûr ? Les utilisateurs sélectionnés seront approuvés et notifiés par e-mail.',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => 'Êtes-vous vraiment sûr ? Les utilisateurs sélectionnés seront supprimés et notifiés par e-mail.',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Êtes-vous vraiment sûr ? Les utilisateurs qui ne sont pas affectés à un autre groupe sont automatiquement affectés au groupe par défaut.',
  'Are you sure that you want to delete following user?' => 'Êtes-vous sûr de vouloir supprimer les utilisateurs suivants ?',
  'Cancel' => 'Annuler',
  'Click here to review' => 'Gérer',
  'Confirm user deletion' => 'Confirmer la suppression',
  'Could not approve the user!' => 'Impossible d’accepter l’utilisateur ou l’utilisatrice !',
  'Could not decline the user!' => 'Impossible de refuser l’utilisateur ou l’utilisatrice !',
  'Could not load category.' => 'Impossible de charger la catégorie.',
  'Create new group' => 'Ajouter un groupe',
  'Create new profile category' => 'Créer une nouvelle catégorie de profil',
  'Create new profile field' => 'Créer nouveau champ de profil',
  'Deactivate' => 'Désactiver',
  'Deactivate individual profile permissions?' => 'Désactiver les autorisations de profil individuel ?',
  'Decline' => 'Refuser',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Refuser et supprimer l\'utilisateur : <strong>{displayName}</strong>',
  'Decline all selected' => 'Refuser tous les sélectionnés',
  'Default' => 'Par défaut',
  'Default Profile Permissions' => 'Autorisations de profil par défaut',
  'Default Sorting' => 'Tri par défaut',
  'Default content of the registration approval email' => 'Contenu du message d\'approbation d\'inscription envoyé par e-mail',
  'Default content of the registration denial email' => 'Contenu du message de refus d\'inscription envoyée par e-mail',
  'Default group can not be deleted!' => 'Le groupe par défaut ne peut pas être supprimé !',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Temporisation d\'inactivité par défaut, déconnexion automatique (en secondes, optionnel)',
  'Default user profile visibility' => 'Visibilité par défaut des profils utilisateurs',
  'Delete' => 'Supprimer',
  'Delete All' => 'Supprimer tout',
  'Delete all contributions of this user' => 'Supprimer toute contribution de cet utilisateur',
  'Delete invitation' => 'Supprimer l’invitation',
  'Delete invitation?' => 'Supprimer l\'invitation ?',
  'Delete spaces which are owned by this user' => 'Supprimer les espaces détenus par cet utilisateur',
  'Deleted' => 'Supprimé',
  'Deleted invitation' => 'Invitation supprimée',
  'Deleted users' => 'Utilisateurs supprimés',
  'Disable' => 'Désactiver',
  'Disabled' => 'Désactivé',
  'Disabled users' => 'Utilisateurs désactivés',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Ne pas modifier les espaces réservés comme {displayName} si vous voulez que ceux-ci soient automatiquement remplis par le système. Pour réinitialiser les champs de contenu de l\'e-mail avec les paramètres par défaut, laisser les vides.',
  'Edit' => 'Modifier',
  'Edit category' => 'Modifier la catégorie',
  'Edit profile category' => 'Modifier la catégorie de profil',
  'Edit profile field' => 'Modifier le champ de profil',
  'Edit user: {name}' => 'Modifier l\'utilisateur : {name}',
  'Enable' => 'Activer',
  'Enable individual profile permissions' => 'Activer les autorisations de profil individuel',
  'Enabled' => 'Activé',
  'First name' => 'Prénom',
  'Group Manager' => 'Administrateur du groupe',
  'Group not found!' => 'Groupe non trouvé !',
  'Group user not found!' => 'Groupe d\'utilisateur non trouvé !',
  'Groups' => 'Groupes',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => 'Bonjour {displayName}, Votre compte a été activé. Cliquez ici pour vous connecter : {loginUrl} Cordialement {AdminName}',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => 'Bonjour {displayName}, Votre demande de compte a été refusée. Cordialement {AdminName}',
  'Here you can create or edit profile categories and fields.' => 'Vous pouvez créer ou modifier ici les catégories et les champs de profil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Si les autorisations de profil individuel ne sont pas autorisées, les paramètres suivants ne sont pas modifiables pour tous les utilisateurs. Si les autorisations de profil individuel sont autorisées, les paramètres sont uniquement définis comme des valeurs par défaut que les utilisateurs peuvent personnaliser. Les entrées suivantes sont alors affichées sous la même forme dans les paramètres du profil de l\'utilisateur :',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Si cette option n\'est pas sélectionnée, le propriétaire des espaces sera transféré sur votre compte.',
  'Impersonate' => 'Incarner',
  'Include captcha in registration form' => 'Activer la protection captcha dans le formulaire d\'inscription',
  'Information 1' => 'Information 1',
  'Information 2' => 'Information 2',
  'Information 3' => 'Information 3',
  'Invisible' => 'Invisible',
  'Invite not found!' => 'Invitation non trouvée !',
  'Last login' => 'Dernière connexion',
  'Last name' => 'Nom',
  'List pending registrations' => 'Liste des inscription en attentes',
  'Make the group selectable at registration.' => 'Permettre de sélectionner le groupe lors de l\'inscription.',
  'Manage group: {groupName}' => 'Gérer le groupe : {groupName}',
  'Manage groups' => 'Gérer les groupes',
  'Manage profile attributes' => 'Gérer les attributs de profil',
  'Member since' => 'Inscrit depuis',
  'Members' => 'Inscrits',
  'Members can invite external users by email' => 'Les membres peuvent inviter des nouvelles personnes par e-mail',
  'Message' => 'Message',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'La valeur minimum est de 20 secondes. Si non définie, la session expirera après 1400 secondes (24 minutes), quelle que soit l\'activité (expiration de session par défaut)',
  'New approval requests' => 'Nouvelle demande d\'approbation',
  'New users can register' => 'Les utilisateurs non identifiés (visiteurs) peuvent s\'inscrire',
  'No' => 'Non',
  'No users were selected.' => 'Aucun utilisateur n\'a été sélectionné.',
  'No value found!' => 'Aucune valeur trouvée !',
  'None' => 'Aucune',
  'Not visible' => 'Masquer',
  'One or more user needs your approval as group admin.' => 'Un ou plusieurs utilisateurs sont en attente d\'approbation.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Applicable uniquement quand l\'accès limité pour les utilisateurs non authentifiés est activé. N\'affecte que les nouveaux utilisateurs.',
  'Overview' => 'Vue d\'ensemble',
  'Password' => 'Mot de passe',
  'Pending approvals' => 'Approbations en attente',
  'Pending user approvals' => 'Approbation d\'utilisateur en attente',
  'People' => 'Membres',
  'Permanently delete' => 'Suppression définitive',
  'Permissions' => 'Permissions',
  'Prioritised User Group' => 'Groupe utilisateur priorisé',
  'Profile Permissions' => 'Autorisations du profil',
  'Profiles' => 'Profils',
  'Protected' => 'Protégée',
  'Protected group can not be deleted!' => 'Le groupe protégé ne peut pas être supprimé !',
  'Remove from group' => 'Retirer du groupe',
  'Require group admin approval after registration' => 'L\'approbation d\'un administrateur du groupe est requis après l\'enregistrement',
  'Resend invitation email' => 'Renvoyer l\'invitation par e-mail',
  'Save' => 'Enregistrer',
  'Search by name, email or id.' => 'Recherche par nom, e-mail ou ID',
  'Select Groups' => 'Sélectionner un groupe',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Sélectionnez un groupe prioritaire dont les membres sont affichés avant tous les autres lorsque l\'option de tri "Par défaut" est sélectionnée. Les utilisateurs au sein du groupe et les utilisateurs en dehors du groupe sont en outre triés en fonction de leur dernière connexion.',
  'Select the profile fields you want to add as columns' => 'Sélectionnez les champs de profil que vous souhaitez ajouter en tant que colonnes',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Sélectionnez les informations relatives à l\'utilisateur qui doivent être affichées dans la vue d\'ensemble "Membres". Vous pouvez sélectionner tous les champs de profil, même ceux que vous avez créés individuellement.',
  'Send & decline' => 'Envoyer et refuser',
  'Send & save' => 'Enregistrer &amp; Envoyer',
  'Send invitation email' => 'Envoyer l\'invitation par e-mail',
  'Send invitation email again?' => 'Renvoyer l\'invitation par mail ?',
  'Send invite' => 'Envoyer une invitation',
  'Send notifications to users when added to or removed from the group.' => 'Envoyez des notifications aux utilisateurs lorsqu\'ils sont ajoutés ou retirés du groupe.',
  'Settings' => 'Paramètres',
  'Show group selection at registration' => 'Afficher le choix du groupe à l\'inscription',
  'Subject' => 'Sujet',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Les adhésions à l\'espace de tous les membres du groupe seront mises à jour. Cette opération peut prendre jusqu\'à plusieurs minutes.',
  'The following list contains all pending sign-ups and invites.' => 'Cette liste contient toutes les inscriptions et invitations en attente.',
  'The following list contains all registered users awaiting an approval.' => 'Cette liste contient tous les utilisateurs inscrits qui attendent d\'être approuvés.',
  'The registration was approved and the user was notified by email.' => 'L\'inscription a été approuvée et l\'utilisateur a été averti par e-mail.',
  'The registration was declined and the user was notified by email.' => 'L\'inscription a été refusée et l\'utilisateur a été averti par e-mail.',
  'The registrations were approved and the users were notified by email.' => 'Les inscriptions ont été approuvées et les utilisateurs ont été avertis par e-mail.',
  'The registrations were declined and the users were notified by email.' => 'Les inscriptions ont été refusées et les utilisateurs ont été avertis par e-mail.',
  'The selected invitations have been successfully deleted!' => 'Les invitations sélectionnées ont été supprimées avec succès !',
  'The user is the owner of these spaces:' => 'Cet utilisateur est le propriétaire de ces espaces:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Cette option vous permet de déterminer si les utilisateurs peuvent définir des autorisations individuelles pour leurs propres profils.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Cet écran affiche la liste de tous les utilisateurs enregistrés et les commandes pour voir, modifier et supprimer des utilisateurs.',
  'This user owns no spaces.' => 'Cet utilisateur ne possède pas d\'espace.',
  'Unapproved' => 'Non approuvé',
  'User deletion process queued.' => 'Suppression de l\'utilisateur en cours.',
  'User is already a member of this group.' => 'L\'utilisateur est déjà membre de ce groupe.',
  'User not found!' => 'Utilisateur non trouvé.',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Les utilisateurs peuvent être affectés à différents groupes (p.ex. : équipes, départements, etc.) avec des espaces standards, des gestionnaires de groupe et des permissions spécifiques.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'En utilisant cette option, toutes contribution (e.g contenus, commentaires, ou j\'aime) de cet utilisateur serra supprimé définitivement.',
  'View profile' => 'Voir le profil',
  'Visible for members only' => 'Visible par les membres uniquement',
  'Visible for members+guests' => 'Visible par les membres et visiteurs',
  'Will be used as a filter in \'People\'.' => 'Sera utilisé comme un filtre dans "Membres".',
  'Yes' => 'Oui',
  'You can only delete empty categories!' => 'Vous pouvez uniquement supprimer les catégories vides.',
  'You cannot delete yourself!' => 'Vous ne pouvez vous supprimer vous même !',
  'never' => 'jamais',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/fr/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Information</strong>',
  '<strong>Profile</strong> Permissions' => 'Autorisations du <strong>profil</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Paramètres</strong> et configuration',
  '<strong>User</strong> administration' => 'Gestion des <strong>utilisateurs</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Attention:</strong> tous les paramètres d\'autorisation individuels du profil sont réinitialisés!',
  'Accept user: <strong>{displayName}</strong> ' => 'Approuver l\'utilisateur : <strong>{displayName}</strong>',
  'Account' => 'Compte',
  'Account Request for \'{displayName}\' has been approved.' => 'La demande de compte pour "{displayName}" a été acceptée.',
  'Account Request for \'{displayName}\' has been declined.' => 'La demande de compte pour "{displayName}" a été refusée.',
  'Actions' => 'Actions',
  'Active users' => 'Utilisateurs actifs',
  'Add Groups...' => 'Ajouter un groupe',
  'Add new category' => 'Ajouter une catégorie',
  'Add new field' => 'Ajouter un champ',
  'Add new group' => 'Ajouter un groupe',
  'Add new members...' => 'Ajouter des membres...',
  'Add new user' => 'Ajouter un nouvel utilisateur',
  'Administrator group could not be deleted!' => 'Le groupe Administrateur ne peut pas être supprimé!',
  'All open registration invitations were successfully deleted.' => 'Toutes les invitations d\'inscription ont été supprimées avec succès.',
  'All the personal data of this user will be irrevocably deleted.' => 'Toutes les données de cet utilisateur seront irrévocablement supprimées.',
  'Allow' => 'Autoriser',
  'Allow users to block each other' => 'Permettre aux utilisateurs de se bloquer mutuellement',
  'Allow users to set individual permissions for their own profile?' => 'Permettre aux utilisateurs de définir des autorisations individuelles pour leur propre profil ?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Autoriser un accès limité pour les utilisateurs non identifiés (visiteurs)',
  'Applied to new or existing users without any other group membership.' => 'Appliqué aux utilisateurs nouveaux ou existants sans autre appartenance à un groupe.',
  'Apply' => 'Appliquer',
  'Approve' => 'Approuver',
  'Approve all selected' => 'Approuver tous les sélectionnés',
  'Are you really sure that you want to disable this user?' => 'Êtes-vous vraiment sûr de vouloir désactiver cet utilisateur ?',
  'Are you really sure that you want to enable this user?' => 'Êtes-vous vraiment sûr de vouloir activer cet utilisateur ?',
  'Are you really sure that you want to impersonate this user?' => 'Êtes-vous sûr de vouloir emprunter l’identité cet utilisateur ?',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => 'Êtes-vous vraiment sûr ? Les utilisateurs sélectionnés seront approuvés et notifiés par e-mail.',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => 'Êtes-vous vraiment sûr ? Les utilisateurs sélectionnés seront supprimés et notifiés par e-mail.',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Êtes-vous vraiment sûr ? Les utilisateurs qui ne sont pas affectés à un autre groupe sont automatiquement affectés au groupe par défaut.',
  'Are you sure that you want to delete following user?' => 'Êtes-vous sûr de vouloir supprimer les utilisateurs suivants ?',
  'Cancel' => 'Annuler',
  'Click here to review' => 'Gérer',
  'Confirm user deletion' => 'Confirmer la suppression',
  'Could not approve the user!' => 'Impossible d’accepter l’utilisateur ou l’utilisatrice !',
  'Could not decline the user!' => 'Impossible de refuser l’utilisateur ou l’utilisatrice !',
  'Could not load category.' => 'Impossible de charger la catégorie.',
  'Create new group' => 'Ajouter un groupe',
  'Create new profile category' => 'Créer une nouvelle catégorie de profil',
  'Create new profile field' => 'Créer nouveau champ de profil',
  'Deactivate' => 'Désactiver',
  'Deactivate individual profile permissions?' => 'Désactiver les autorisations de profil individuel ?',
  'Decline' => 'Refuser',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Refuser et supprimer l\'utilisateur : <strong>{displayName}</strong>',
  'Decline all selected' => 'Refuser tous les sélectionnés',
  'Default' => 'Par défaut',
  'Default Profile Permissions' => 'Autorisations de profil par défaut',
  'Default Sorting' => 'Tri par défaut',
  'Default content of the registration approval email' => 'Contenu du message d\'approbation d\'inscription envoyé par e-mail',
  'Default content of the registration denial email' => 'Contenu du message de refus d\'inscription envoyée par e-mail',
  'Default group can not be deleted!' => 'Le groupe par défaut ne peut pas être supprimé !',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Temporisation d\'inactivité par défaut, déconnexion automatique (en secondes, optionnel)',
  'Default user profile visibility' => 'Visibilité par défaut des profils utilisateurs',
  'Delete' => 'Supprimer',
  'Delete All' => 'Supprimer tout',
  'Delete all contributions of this user' => 'Supprimer toute contribution de cet utilisateur',
  'Delete invitation' => 'Supprimer l’invitation',
  'Delete invitation?' => 'Supprimer l\'invitation ?',
  'Delete spaces which are owned by this user' => 'Supprimer les espaces détenus par cet utilisateur',
  'Deleted' => 'Supprimé',
  'Deleted invitation' => 'Invitation supprimée',
  'Deleted users' => 'Utilisateurs supprimés',
  'Disable' => 'Désactiver',
  'Disabled' => 'Désactivé',
  'Disabled users' => 'Utilisateurs désactivés',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Ne pas modifier les espaces réservés comme {displayName} si vous voulez que ceux-ci soient automatiquement remplis par le système. Pour réinitialiser les champs de contenu de l\'e-mail avec les paramètres par défaut, laisser les vides.',
  'Edit' => 'Modifier',
  'Edit category' => 'Modifier la catégorie',
  'Edit profile category' => 'Modifier la catégorie de profil',
  'Edit profile field' => 'Modifier le champ de profil',
  'Edit user: {name}' => 'Modifier l\'utilisateur : {name}',
  'Enable' => 'Activer',
  'Enable individual profile permissions' => 'Activer les autorisations de profil individuel',
  'Enabled' => 'Activé',
  'First name' => 'Prénom',
  'Group Manager' => 'Administrateur du groupe',
  'Group not found!' => 'Groupe non trouvé !',
  'Group user not found!' => 'Groupe d\'utilisateur non trouvé !',
  'Groups' => 'Groupes',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => 'Bonjour {displayName}, Votre compte a été activé. Cliquez ici pour vous connecter : {loginUrl} Cordialement {AdminName}',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => 'Bonjour {displayName}, Votre demande de compte a été refusée. Cordialement {AdminName}',
  'Here you can create or edit profile categories and fields.' => 'Vous pouvez créer ou modifier ici les catégories et les champs de profil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Si les autorisations de profil individuel ne sont pas autorisées, les paramètres suivants ne sont pas modifiables pour tous les utilisateurs. Si les autorisations de profil individuel sont autorisées, les paramètres sont uniquement définis comme des valeurs par défaut que les utilisateurs peuvent personnaliser. Les entrées suivantes sont alors affichées sous la même forme dans les paramètres du profil de l\'utilisateur :',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Si cette option n\'est pas sélectionnée, le propriétaire des espaces sera transféré sur votre compte.',
  'Impersonate' => 'Emprunter l’identité',
  'Include captcha in registration form' => 'Activer la protection captcha dans le formulaire d\'inscription',
  'Information 1' => 'Information 1',
  'Information 2' => 'Information 2',
  'Information 3' => 'Information 3',
  'Invisible' => 'Invisible',
  'Invite not found!' => 'Invitation non trouvée !',
  'Last login' => 'Dernière connexion',
  'Last name' => 'Nom',
  'List pending registrations' => 'Liste des inscription en attentes',
  'Make the group selectable at registration.' => 'Permettre de sélectionner le groupe lors de l\'inscription.',
  'Manage group: {groupName}' => 'Gérer le groupe : {groupName}',
  'Manage groups' => 'Gérer les groupes',
  'Manage profile attributes' => 'Gérer les attributs de profil',
  'Member since' => 'Inscrit depuis',
  'Members' => 'Inscrits',
  'Members can invite external users by email' => 'Les membres peuvent inviter des nouvelles personnes par e-mail',
  'Message' => 'Message',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'La valeur minimum est de 20 secondes. Si non définie, la session expirera après 1400 secondes (24 minutes), quelle que soit l\'activité (expiration de session par défaut)',
  'New approval requests' => 'Nouvelle demande d\'approbation',
  'New users can register' => 'Les utilisateurs non identifiés (visiteurs) peuvent s\'inscrire',
  'No' => 'Non',
  'No users were selected.' => 'Aucun utilisateur n\'a été sélectionné.',
  'No value found!' => 'Aucune valeur trouvée !',
  'None' => 'Aucune',
  'Not visible' => 'Masquer',
  'One or more user needs your approval as group admin.' => 'Un ou plusieurs utilisateurs sont en attente d\'approbation.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Applicable uniquement quand l\'accès limité pour les utilisateurs non authentifiés est activé. N\'affecte que les nouveaux utilisateurs.',
  'Overview' => 'Vue d\'ensemble',
  'Password' => 'Mot de passe',
  'Pending approvals' => 'Approbations en attente',
  'Pending user approvals' => 'Approbation d\'utilisateur en attente',
  'People' => 'Membres',
  'Permanently delete' => 'Suppression définitive',
  'Permissions' => 'Permissions',
  'Prioritised User Group' => 'Groupe utilisateur priorisé',
  'Profile Permissions' => 'Autorisations du profil',
  'Profiles' => 'Profils',
  'Protected' => 'Protégée',
  'Protected group can not be deleted!' => 'Le groupe protégé ne peut pas être supprimé !',
  'Remove from group' => 'Retirer du groupe',
  'Require group admin approval after registration' => 'L\'approbation d\'un administrateur du groupe est requis après l\'enregistrement',
  'Resend invitation email' => 'Renvoyer l\'invitation par e-mail',
  'Save' => 'Enregistrer',
  'Search by name, email or id.' => 'Recherche par nom, e-mail ou ID',
  'Select Groups' => 'Sélectionner un groupe',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Sélectionnez un groupe prioritaire dont les membres sont affichés avant tous les autres lorsque l\'option de tri "Par défaut" est sélectionnée. Les utilisateurs au sein du groupe et les utilisateurs en dehors du groupe sont en outre triés en fonction de leur dernière connexion.',
  'Select the profile fields you want to add as columns' => 'Sélectionnez les champs de profil que vous souhaitez ajouter en tant que colonnes',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Sélectionnez les informations relatives à l\'utilisateur qui doivent être affichées dans la vue d\'ensemble "Membres". Vous pouvez sélectionner tous les champs de profil, même ceux que vous avez créés individuellement.',
  'Send & decline' => 'Envoyer et refuser',
  'Send & save' => 'Enregistrer &amp; Envoyer',
  'Send invitation email' => 'Envoyer l\'invitation par e-mail',
  'Send invitation email again?' => 'Renvoyer l\'invitation par mail ?',
  'Send invite' => 'Envoyer une invitation',
  'Send notifications to users when added to or removed from the group.' => 'Envoyez des notifications aux utilisateurs lorsqu\'ils sont ajoutés ou retirés du groupe.',
  'Settings' => 'Paramètres',
  'Show group selection at registration' => 'Afficher le choix du groupe à l\'inscription',
  'Subject' => 'Sujet',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Les adhésions à l\'espace de tous les membres du groupe seront mises à jour. Cette opération peut prendre jusqu\'à plusieurs minutes.',
  'The following list contains all pending sign-ups and invites.' => 'Cette liste contient toutes les inscriptions et invitations en attente.',
  'The following list contains all registered users awaiting an approval.' => 'Cette liste contient tous les utilisateurs inscrits qui attendent d\'être approuvés.',
  'The registration was approved and the user was notified by email.' => 'L\'inscription a été approuvée et l\'utilisateur a été averti par e-mail.',
  'The registration was declined and the user was notified by email.' => 'L\'inscription a été refusée et l\'utilisateur a été averti par e-mail.',
  'The registrations were approved and the users were notified by email.' => 'Les inscriptions ont été approuvées et les utilisateurs ont été avertis par e-mail.',
  'The registrations were declined and the users were notified by email.' => 'Les inscriptions ont été refusées et les utilisateurs ont été avertis par e-mail.',
  'The selected invitations have been successfully deleted!' => 'Les invitations sélectionnées ont été supprimées avec succès !',
  'The user is the owner of these spaces:' => 'Cet utilisateur est le propriétaire de ces espaces:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Cette option vous permet de déterminer si les utilisateurs peuvent définir des autorisations individuelles pour leurs propres profils.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Cet écran affiche la liste de tous les utilisateurs enregistrés et les commandes pour voir, modifier et supprimer des utilisateurs.',
  'This user owns no spaces.' => 'Cet utilisateur ne possède pas d\'espace.',
  'Unapproved' => 'Non approuvé',
  'User deletion process queued.' => 'Suppression de l\'utilisateur en cours.',
  'User is already a member of this group.' => 'L\'utilisateur est déjà membre de ce groupe.',
  'User not found!' => 'Utilisateur non trouvé.',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Les utilisateurs peuvent être affectés à différents groupes (p.ex. : équipes, départements, etc.) avec des espaces standards, des gestionnaires de groupe et des permissions spécifiques.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'En utilisant cette option, toutes contribution (e.g contenus, commentaires, ou j\'aime) de cet utilisateur serra supprimé définitivement.',
  'View profile' => 'Voir le profil',
  'Visible for members only' => 'Visible par les membres uniquement',
  'Visible for members+guests' => 'Visible par les membres et visiteurs',
  'Will be used as a filter in \'People\'.' => 'Sera utilisé comme un filtre dans "Membres".',
  'Yes' => 'Oui',
  'You can only delete empty categories!' => 'Vous pouvez uniquement supprimer les catégories vides.',
  'You cannot delete yourself!' => 'Vous ne pouvez vous supprimer vous même !',
  'never' => 'jamais',
);
